<?php
/* **************************************************************************** *

 * Curl.inc.php
 * @package	Core
 * @copyright:	Copyright (c) 2008 Martin Novák. All rights reserved
 * @license	GNU/AGPL http://www.gnu.org/licenses/agpl.html

 * Albireo is free software! You can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU Affero General Public License for more details.

 This script description:
 This Class gives tool to work with curl extension to communicate between
 servers.

 Properties:
    none

 Public Methods:
    none

 * **************************************************************************** */

class Curl {

    private $headers;
    private $user_agent;
    private $compression;
    private $cookie_file;
    private $proxy;
    private $process;

    public function __construct ( $cookies = true, $cookie = "cookies.db", $compression = "gzip", $proxy = "" )
    {
        $this -> headers [] = "Accept: image/gif, image/x-bitmap, image/jpeg, image/pjpeg";
        $this -> headers [] = "Connection: Keep-Alive";
        $this -> headers [] = "Content-type: application/x-www-form-urlencoded;charset=UTF-8";
        $this -> user_agent = $_SERVER [ "SERVER_SOFTWARE" ].' *'. $_SERVER [ "HTTP_HOST" ] . substr ( $_SERVER [ "SCRIPT_NAME" ], 0, strrpos ( $_SERVER [ "SCRIPT_NAME" ], "/" ) ) .'* (Albireo I version '. Tools::baseSettings () -> getSetting ( "version" ) .')';
        $this -> compression = $compression;
        $this -> proxy = $proxy;
        $this -> cookies = $cookies;
        if ( $this -> cookies == true ) $this -> cookie ( $cookie );
    }

    private function CurlIni ( $url )
    {
        $this -> process = curl_init ();
        curl_setopt ( $this -> process, CURLOPT_URL, $url );
        curl_setopt ( $this -> process, CURLOPT_SSL_VERIFYPEER, 0 );
        curl_setopt ( $this -> process, CURLOPT_SSL_VERIFYHOST, 0 );
        curl_setopt ( $this -> process, CURLOPT_SSLVERSION, 3 );
        curl_setopt ( $this -> process, CURLOPT_HTTPHEADER, $this -> headers );
        curl_setopt ( $this -> process, CURLOPT_HEADER, 0 );
        curl_setopt ( $this -> process, CURLOPT_USERAGENT, $this -> user_agent );
        if ( $this -> cookies == true ) curl_setopt ( $this -> process, CURLOPT_COOKIEFILE, $this -> cookie_file );
        if ( $this -> cookies == true ) curl_setopt ( $this -> process, CURLOPT_COOKIEJAR, $this -> cookie_file );
        curl_setopt ( $this -> process, CURLOPT_ENCODING , $this -> compression );
        curl_setopt ( $this -> process, CURLOPT_TIMEOUT, 30 );
        if ( $this -> proxy ) curl_setopt ( $this -> process, CURLOPT_PROXY, $this -> proxy );
        curl_setopt ( $this -> process, CURLOPT_RETURNTRANSFER, 1 );
        curl_setopt ( $this -> process, CURLOPT_FOLLOWLOCATION, 1 );
    }

    private function httpAuthentication ( $login ) // $login = login:pasword
    {
        curl_setopt ( $ch, CURLOPT_USERPWD, $login );
        curl_setopt ( $ch, CURLOPT_HTTPAUTH, CURLAUTH_ANY );
    }

    private function cookie ( $cookie_file )
    {
        if ( file_exists ( $cookie_file ) ) {
            $this -> cookie_file = $cookie_file;
        } else {
            if ( !fopen ( $cookie_file, 'w' ) ) return false;
            $this -> cookie_file = $cookie_file;
            return true;
        }
    }

    public function get ( $url, $httpauth = "" ) {
        $this -> CurlIni ( $url );
        if ( $httpauth != "" ) $this -> httpAuthentication ( $httpauth );
        $return = curl_exec ( $this -> process );
        curl_close( $this -> process );
        return $return;
    }

    public function post ( $url, $data ) {
        $this -> CurlIni ( $url );
        curl_setopt ( $this -> process, CURLOPT_POSTFIELDS, $data );
        curl_setopt ( $this -> process, CURLOPT_POST, 1 );
        $return = curl_exec ( $this -> process );
        curl_close ( $this -> process );
        return $return;
    }

}
?>